summaryrefslogtreecommitdiff
path: root/indra/newview/llflickrconnect.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llflickrconnect.cpp')
-rw-r--r--indra/newview/llflickrconnect.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/llflickrconnect.cpp b/indra/newview/llflickrconnect.cpp
index 62c8110ea7..3da3ef22b2 100644
--- a/indra/newview/llflickrconnect.cpp
+++ b/indra/newview/llflickrconnect.cpp
@@ -280,11 +280,11 @@ void LLFlickrConnect::openFlickrWeb(std::string url)
p.url(url).allow_address_entry(false);
p.url(url).allow_back_forward_navigation(false);
p.url(url).trusted_content(true);
- LLFloater *floater = LLFloaterReg::showInstance("fbc_web", p);
+ LLFloater *floater = LLFloaterReg::showInstance("flickr_web", p);
//the internal web browser has a bug that prevents it from gaining focus unless a mouse event occurs first (it seems).
//So when showing the internal web browser, set focus to it's containing floater "fbc_web". When a mouse event
//occurs on the "webbrowser" panel part of the floater, a mouse cursor will properly show and the "webbrowser" will gain focus.
//fbc_web floater contains the "webbrowser" panel. JIRA: ACME-744
gFocusMgr.setKeyboardFocus( floater );
//LLUrlAction::openURLExternal(url);
@@ -280,11 +280,11 @@ void LLFlickrConnect::openFlickrWeb(std::string url)
//the internal web browser has a bug that prevents it from gaining focus unless a mouse event occurs first (it seems).
- //So when showing the internal web browser, set focus to it's containing floater "fbc_web". When a mouse event
+ //So when showing the internal web browser, set focus to it's containing floater "flickr_web". When a mouse event
//occurs on the "webbrowser" panel part of the floater, a mouse cursor will properly show and the "webbrowser" will gain focus.
@@ -280,11 +280,11 @@ void LLFlickrConnect::openFlickrWeb(std::string url)
//occurs on the "webbrowser" panel part of the floater, a mouse cursor will properly show and the "webbrowser" will gain focus.
- //fbc_web floater contains the "webbrowser" panel. JIRA: ACME-744
+ //flickr_web floater contains the "webbrowser" panel. JIRA: ACME-744
gFocusMgr.setKeyboardFocus( floater );
//LLUrlAction::openURLExternal(url);